@@ -8,6 +8,16 @@ source "${SCRIPT_PATH}/_common.sh"
 LOG_FILE="${LOG_DIR}/installer_$(date +"%Y%m%d_%H%M").log"
 
 main() {
+    if findmnt -no OPTIONS /tmp | grep -qw noexec; then
+      echo "/tmp is mounted with noexec. Please remount /tmp with exec option and try again."
+      exit 1
+    fi
+
+    if (( $(df --output=avail -m /tmp | tail -1) < 100 )); then
+      echo "/tmp has less than 100 MB free. Please remount /tmp with more space and try again."
+      exit 1
+    fi
+
     local rdi_cli_dir_name; rdi_cli_dir_name=$(get_rdi_cli_dir) || exit 1
     local redis_di_path="${SCRIPT_PATH}/deps/rdi-cli/${rdi_cli_dir_name}/redis-di"
 
